@@ -53,7 +53,7 @@ Catalyst::Component - Catalyst Component Base Class
 This is the universal base class for Catalyst components
 (Model/View/Controller).
 
-It provides you with a generic new() for instantiation through Catalyst's
+It provides you with a generic new() for component construction through Catalyst's
 component loader with config() support and a process() method placeholder.
 
 =cut
@@ -127,7 +127,7 @@ sub config {
         # TODO maybe this should be a ClassData option?
         my $class = blessed($self) || $self;
         my $meta = Class::MOP::get_metaclass_by_name($class);
-        unless ($meta->has_package_symbol('$_config')) {
+        unless (${ $meta->get_or_add_package_symbol('$_config') }) {
             # Call merge_hashes to ensure we deep copy the parent
             # config onto the subclass
             $self->_config( Catalyst::Utils::merge_hashes($config, {}) );
@@ -180,7 +180,7 @@ The arguments are expected to be a hashref and are merged with the
 C<< __PACKAGE__->config >> hashref before calling C<< ->new >>
 to instantiate the component.
 
-You can override it in your components to do custom instantiation, using
+You can override it in your components to do custom construction, using
 something like this:
 
   sub COMPONENT {
